@@ -1,4 +1,4 @@
-## $Id: bouts.R 219 2009-05-07 01:58:04Z sluque $
+## $Id: bouts.R 335 2010-07-25 20:27:22Z sluque $
 
 "logit" <- function(p) log(p / (1 - p))
 
@@ -184,8 +184,7 @@
 "bouts2.ll" <- function(x) # 2-process Poisson
 {
     function(p, lambda1, lambda2) {
-        -sum(log(p * lambda1 * exp(-lambda1 * x) +
-                 (1 - p) * lambda2 * exp(-lambda2 * x)))
+        -sum(diveMove::bouts2.mleFUN(x, p, lambda1, lambda2))
     }
 }
 
@@ -195,8 +194,7 @@
         p <- unLogit(p)
         lambda1 <- exp(lambda1)
         lambda2 <- exp(lambda2)
-        -sum(log(p * lambda1 * exp(-lambda1 * x) +
-                 (1 - p) * lambda2 * exp(-lambda2 * x)))
+        -sum(diveMove::bouts2.mleFUN(x, p, lambda1, lambda2))
     }
 }
 
